@@ -47,7 +47,3 @@ class Calculator(QObject):
     def _calculate(self):
         self._out = self._in1 + self._in2
         self.outChanged.emit(self._out)
-
-    @Property('QVariant')
-    def something(self):
-        return [1, 2, 4, 5]
